views

package
v0.0.0-...-4026353 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 4, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ExchangesList = []Exchange{
	{
		Name:                  "Swapuz",
		ShortCode:             "swapuz",
		KYCScore:              0,
		URL:                   "https://www.swapuz.com",
		LogoURL:               "/exchanges/swapuz.png",
		NoTextURL:             "/exchanges/no-text/swapuz.png",
		Description:           "Swapuz is a crypto swap platform that was designed to preserve the complete anonymity of its users.",
		CGShield:              true,
		CGAmount:              "0.01 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.01,
		BTCDepositAddress:     "bc1q59w76hllasumgaxdrnn45aue7p5uq44dy4wfgx",
		TrustpilotURL:         "https://www.trustpilot.com/review/swapuz.com",
		TrustpilotRating:      4.6,
		TrustpilotReviewCount: 107,
	},
	{
		Name:                  "AlfaCash",
		ShortCode:             "alfacash",
		KYCScore:              2,
		URL:                   "https://www.alfacash.com",
		LogoURL:               "/exchanges/alfacash.svg",
		NoTextURL:             "/exchanges/no-text/alfacash.jpg",
		Description:           "A reliable cryptocurrency exchange offering competitive rates and fast transactions.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/alfa.cash",
		TrustpilotRating:      3.4,
		TrustpilotReviewCount: 74,
	},
	{
		Name:                  "ChangeHero",
		ShortCode:             "changehero",
		KYCScore:              2,
		URL:                   "https://changehero.io",
		LogoURL:               "/exchanges/changehero.svg",
		NoTextURL:             "/exchanges/no-text/changehero.jpeg",
		Description:           "Fast and secure cryptocurrency exchange with no registration required.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/changehero.io",
		TrustpilotRating:      4.3,
		TrustpilotReviewCount: 419,
	},
	{
		Name:                  "ChangeNOW",
		ShortCode:             "changenow",
		KYCScore:              2,
		URL:                   "https://changenow.io",
		LogoURL:               "/exchanges/changenow.svg",
		NoTextURL:             "",
		Description:           "Limitless crypto exchange with over 500 cryptocurrencies and no registration.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/changenow.io",
		TrustpilotRating:      4.5,
		TrustpilotReviewCount: 12737,
	},
	{
		Name:                  "FixedFloat",
		ShortCode:             "fixedfloat",
		KYCScore:              2,
		URL:                   "https://ff.io",
		LogoURL:               "/exchanges/fixedfloat-v2.svg",
		NoTextURL:             "/exchanges/no-text/fixedfloat.svg",
		Description:           "Lightning-fast cryptocurrency exchange with fixed and floating rates.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/ff.io",
		TrustpilotRating:      4.3,
		TrustpilotReviewCount: 2162,
	},
	{
		Name:                  "PegasusSwap",
		ShortCode:             "pegasusswap",
		KYCScore:              0,
		URL:                   "https://pegasusswap.com",
		LogoURL:               "/exchanges/pegasusswap.png",
		NoTextURL:             "",
		Description:           "PegasusSwap is an exchange service that will facilitate the exchange of cryptocurrencies! Speed, reliability and trust",
		CGShield:              true,
		CGAmount:              "0.1 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.1,
		TrustpilotURL:         "https://www.trustpilot.com/review/pegasusswap.com",
		BTCDepositAddress:     "bc1qwudg2r255dal6hsuq5c87f402rjy7xyknm0v8r",
		TrustpilotRating:      4.5,
		TrustpilotReviewCount: 15,
	},
	{
		Name:                  "QuickEx",
		ShortCode:             "quickex",
		KYCScore:              1,
		URL:                   "https://quickex.io",
		LogoURL:               "/exchanges/quickex.png",
		NoTextURL:             "",
		Description:           "A reliable and secure cryptocurrency exchange platform operating since 2018.",
		CGShield:              true,
		CGAmount:              "1000 USDT",
		CGSinStable:           true,
		CGSAmountFloat:        1000,
		ETHDepositAddress:     "0xcd337ECd07690BF1537E56Cd22C6FD932f184634",
		TrustpilotURL:         "https://www.trustpilot.com/review/quickex.io",
		TrustpilotRating:      4.2,
		TrustpilotReviewCount: 46,
	},
	{
		Name:                  "Nanswap",
		ShortCode:             "nanswap",
		KYCScore:              2,
		URL:                   "https://nanswap.com",
		LogoURL:               "/exchanges/nanswap.svg",
		NoTextURL:             "",
		Description:           "Simple and efficient cryptocurrency exchange with competitive rates.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/nanswap.com",
		TrustpilotRating:      4.1,
		TrustpilotReviewCount: 30,
	},
	{
		Name:                  "SimpleSwap",
		ShortCode:             "simpleswap",
		KYCScore:              2,
		URL:                   "https://simpleswap.io",
		LogoURL:               "/exchanges/simpleswap.svg",
		NoTextURL:             "/exchanges/no-text/simpleswap.png",
		Description:           "Easy-to-use cryptocurrency exchange with over 1500 cryptocurrencies.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/simpleswap.io",
		TrustpilotRating:      4.5,
		TrustpilotReviewCount: 2959,
	},
	{
		Name:                  "StealthEX",
		ShortCode:             "stealthex",
		KYCScore:              1,
		URL:                   "https://stealthex.io",
		LogoURL:               "/exchanges/stealthex.svg",
		NoTextURL:             "/exchanges/no-text/stealthex.png",
		Description:           "Anonymous crypto exchange with no registration and instant swaps.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/stealthex.io",
		TrustpilotRating:      4.5,
		TrustpilotReviewCount: 390,
	},
	{
		Name:                  "WizardSwap",
		ShortCode:             "wizardswap",
		KYCScore:              0,
		URL:                   "https://wizardswap.io",
		LogoURL:               "/exchanges/wizardswap.png",
		NoTextURL:             "",
		Description:           "Decentralized exchange focusing on privacy and security.",
		CGShield:              true,
		CGAmount:              "0.02 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.02,
		BTCDepositAddress:     "bc1q6sy894sz2me9x4ptzkr6vgxuw2aud3dlqy7tkf",
		TrustpilotURL:         "https://www.trustpilot.com/review/wizardswap.io",
		TrustpilotRating:      3,
		TrustpilotReviewCount: 4,
	},
	{
		Name:                  "Exolix",
		ShortCode:             "exolix",
		KYCScore:              0,
		URL:                   "https://exolix.com/",
		LogoURL:               "/exchanges/exolix.png",
		NoTextURL:             "/exchanges/no-text/exolix.png",
		Description:           "Сrypto exchange aggregator that allows you to swap crypto in a quick, simple and instant way.",
		CGShield:              true,
		CGAmount:              "0.05 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.05,
		BTCDepositAddress:     "bc1q5h3zt9rau6cjscq97q6ygyczcgfdr3r6gylzsn",
		TrustpilotURL:         "https://www.trustpilot.com/review/exolix.com",
		TrustpilotRating:      4.5,
		TrustpilotReviewCount: 370,
	},
	{
		Name:                  "GoDex",
		ShortCode:             "godex",
		KYCScore:              1,
		URL:                   "https://godex.io/",
		LogoURL:               "/exchanges/godex.svg",
		NoTextURL:             "/exchanges/no-text/godex.jpg",
		Description:           "Cryptocurrency exchange with instant swaps and competitive rates.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/godex.io",
		TrustpilotRating:      4.4,
		TrustpilotReviewCount: 1010,
	},
	{
		Name:                  "LetsExchange",
		ShortCode:             "letsexchange",
		KYCScore:              1,
		URL:                   "https://letsexchange.io/",
		LogoURL:               "/exchanges/letsexchange.svg",
		NoTextURL:             "/exchanges/no-text/letsexchange.svg",
		Description:           "Cryptocurrency exchange with instant swaps and competitive rates.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/letsexchange.io",
		TrustpilotRating:      4.7,
		TrustpilotReviewCount: 573,
	},
	{
		Name:                  "BitcoinVN",
		ShortCode:             "bitcoinvn",
		KYCScore:              1,
		URL:                   "https://bitcoinvn.io/",
		LogoURL:               "/exchanges/bitcoinvn.png",
		NoTextURL:             "/exchanges/no-text/bitcoinvn.png",
		Description:           "Cryptocurrency exchange with instant swaps and competitive rates.",
		CGShield:              true,
		CGAmount:              "0.025 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.025,
		BTCDepositAddress:     "bc1q44kl9mfdntmehvy3cx8pxdc2vw43q7cr4tzyvw",
		TrustpilotURL:         "https://www.trustpilot.com/review/bitcoinvn.io",
		TrustpilotRating:      4.5,
		TrustpilotReviewCount: 181,
	},
	{
		Name:                  "ETZSwap",
		ShortCode:             "etzswap",
		KYCScore:              0,
		URL:                   "https://etz-swap.com/",
		LogoURL:               "/exchanges/etz.png",
		NoTextURL:             "",
		Description:           "Discover seamless crypto swaps with ETZ-Swap: trade 1000+ assets (BTC, ETH, XMR), enjoy fast transactions, fair rates & full transparency.",
		CGShield:              true,
		CGAmount:              "0.0435 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.0435,
		BTCDepositAddress:     "bc1qvgn9kvv4mukq26jmxsr5qr96v0vt0hwyv2yad8",
		TrustpilotURL:         "https://www.trustpilot.com/review/etz-swap.com",
		TrustpilotRating:      4.8,
		TrustpilotReviewCount: 60,
	},
	{
		Name:                  "THORChain",
		ShortCode:             "thorchain",
		KYCScore:              0,
		URL:                   "https://thorchain.org/",
		LogoURL:               "/exchanges/no-text/thorchain.png",
		NoTextURL:             "",
		Description:           "Decentralized and censorship-resistant infrastructure for trading Bitcoin, Ethereum, Tether (USDT), USDC, and other native assets.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/thorchain.org",
		TrustpilotRating:      0,
		TrustpilotReviewCount: 0,
	},
	{
		Name:                  "BitXChange",
		ShortCode:             "bitxchange",
		KYCScore:              1,
		URL:                   "https://www.bitxchange.io/",
		LogoURL:               "/exchanges/no-text/bitxchange.png",
		NoTextURL:             "",
		Description:           "BitXchange is a non-custodial, anonymous crypto exchange supporting over 400 assets, including popular tokens such as Bitcoin, Ethereum, Zcash, Monero, and many more",
		CGShield:              true,
		CGAmount:              "0.05 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.05,
		BTCDepositAddress:     "bc1qll0wdq0t35kgtrxldrzqv0qvyfvmas234s2se2",
		TrustpilotURL:         "https://www.trustpilot.com/review/bitxchange.io",
		TrustpilotRating:      4.0,
		TrustpilotReviewCount: 3,
	},
	{
		Name:                  "n.exchange",
		ShortCode:             "nexchange",
		KYCScore:              1,
		URL:                   "https://n.exchange/",
		LogoURL:               "/exchanges/nexchange.PNG",
		NoTextURL:             "/exchanges/no-text/nexchange.png",
		Description:           "n.exchange is a fast, reliable and fully transparent cryptocurrency exchange built by crypto enthusiasts, for crypto enthusiasts.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/n.exchange",
		TrustpilotRating:      4.0,
		TrustpilotReviewCount: 365,
	},
	{
		Name:              "StereoSwap",
		ShortCode:         "stereoswap",
		KYCScore:          1,
		URL:               "https://stereoswap.app",
		LogoURL:           "/exchanges/stereoswap.png",
		NoTextURL:         "/exchanges/no-text/stereoswap.png",
		Description:       "Change 1500+ coins with no limits and no sign-up. Private and secure",
		CGShield:          true,
		CGAmount:          "0.014 BTC",
		CGSinStable:       false,
		CGSAmountFloat:    0.014,
		BTCDepositAddress: "bc1qjqxlyjmpfl0dvgxdgejca74s3ml269lyyzvq9f",
		TrustpilotURL:     "https://www.trustpilot.com/review/stereoswap.app",
		TrustpilotRating:  0,
	},
	{
		Name:                  "Bitania",
		ShortCode:             "bitania",
		KYCScore:              0,
		URL:                   "https://bitania.com/",
		LogoURL:               "/exchanges/bitania.png",
		NoTextURL:             "/exchanges/no-text/bitania.jpg",
		Description:           "Anonymous No-KYC crypto exchange. A privacy-focused platform for buying and selling Litecoin, Monero, Bitcoin, USDT to any Fiat methods.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/bitania.com",
		TrustpilotRating:      0,
		TrustpilotReviewCount: 0,
	},
	{
		Name:                  "CCECash",
		ShortCode:             "ccecash",
		KYCScore:              0,
		URL:                   "https://cce.cash/",
		LogoURL:               "/exchanges/ccecash.svg",
		NoTextURL:             "/exchanges/no-text/ccecash.png",
		Description:           "Allows cross-chain exchange of any cryptocurrency. Safe and reliable. Hold and manage digital assets independently, and no one can access your assets.",
		CGShield:              true,
		CGAmount:              "0.01 BTC",
		CGSinStable:           false,
		CGSAmountFloat:        0.01,
		BTCDepositAddress:     "bc1qdw4mz2ypu32udtgdxgrrn5023wu0kqz33m4949",
		TrustpilotURL:         "https://www.trustpilot.com/review/cce.cash",
		TrustpilotRating:      4.6,
		TrustpilotReviewCount: 29,
	},
	{
		Name:                  "Baltex",
		ShortCode:             "baltex",
		KYCScore:              1,
		URL:                   "https://baltex.io/",
		LogoURL:               "/exchanges/baltex.svg",
		NoTextURL:             "/exchanges/no-text/baltex.svg",
		Description:           "Buy and exchange Bitcoin on Baltex — fast, secure, no limits or KYC. Low fees, instant swaps, and free AML verification.",
		CGShield:              false,
		TrustpilotURL:         "https://www.trustpilot.com/review/baltex.io",
		TrustpilotRating:      4.2,
		TrustpilotReviewCount: 15,
	},
	{
		Name:                  "xmr2cex",
		ShortCode:             "xmr2cex",
		KYCScore:              0,
		URL:                   "https://xmr2cex.com/",
		LogoURL:               "/exchanges/xmr2cex.png",
		NoTextURL:             "",
		Description:           "xmr2cex. 24/7 Zero-KYC Monero Offramp. Get premium, 100% clean coins directly from Binance, Gate, or another top CEX.",
		CGShield:              true,
		CGAmount:              "10,000 USDT",
		CGSAmountFloat:        10000,
		CGSinStable:           true,
		BSCDepositAddress:     "0xcd337ECd07690BF1537E56Cd22C6FD932f184634",
		TrustpilotURL:         "https://www.trustpilot.com/review/xmr2cex.com",
		TrustpilotRating:      0,
		TrustpilotReviewCount: 0,
	},
}
var KYCIncidentRate = "0.041%"

Functions

This section is empty.

Types

type Coin

type Coin struct {
	Ticker  string `json:"ticker"`
	Name    string `json:"name"`
	Network string `json:"network"`
	Icon    string `json:"icon"`
}

type PrizeStatus

type PrizeStatus struct {
	Claimed int
	Total   int
}

Jump to